@@ -1,9 +1,4 @@
 <?php
-/**
- * Prepare the test setup.
- */
-require_once __DIR__ . '/Base.php';
-
 /**
  * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
  *
@@ -13,15 +8,20 @@ require_once __DIR__ . '/Base.php';
  * @subpackage UnitTests
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  */
-class Horde_Image_Exif_ExiftoolTest extends Horde_Image_Test_Exif_Base
+class Horde_Image_Exif_ExiftoolTest extends Horde_Image_Exif_TestBase
 {
     public static function setUpBeforeClass()
     {
-        $config = self::getConfig('IMAGE_EXIF_TEST_CONFIG',
-                                  __DIR__ . '/..');
+        $config = self::getConfig('IMAGE_EXIF_TEST_CONFIG', __DIR__ . '/..');
         if ($config && !empty($config['image']['exiftool'])) {
             self::$_exif = new Horde_Image_Exif_Exiftool(array('exiftool' => $config['image']['exiftool']));
-            parent::setUpBeforeClass();
+        }
+    }
+
+    public function setUp()
+    {
+        if (self::$_exif === null) {
+            $this->markTestSkipped('No exiftool configuration');
         }
     }
 
